@@ -5,7 +5,7 @@ import numpy as np
 import numpy.ma as ma
 import logging
 from cloudnetpy.utils import isscalar
-from cloudnetpy.categorize.datasource import DataSource
+from cloudnetpy.datasource import DataSource
 from model_evaluation.model_metadata import MODELS, VARIABLES
 from model_evaluation.utils import file_exists
 
